::: msl.kcdb.kcdb
    options:
        filters: [
            "!^_",
            "!^check_page_info$",
            "!^to_label$",
            "!^to_countries$",
            "!^to_physics_code$",
        ]
